@@ -1003,20 +1003,21 @@ do_mount_umount (char *filename, gboolean is_mount)
 		return FALSE;
 	
 	if (op){
+		gboolean success = TRUE;
 		char *command;
 		FILE *f;
 		
 		command = g_strconcat (op, " ", buffer, NULL);
 		open_error_pipe ();
 		f = popen (command, "r");
-		if (f == NULL)
-			close_error_pipe (1, _("While running the mount/umount command"));
-		else 
-			close_error_pipe (0, 0);
+		if (f == NULL){
+			success = !close_error_pipe (1, _("While running the mount/umount command"));
+		} else 
+			success = !close_error_pipe (0, 0);
 		pclose (f);
 		
 		g_free (buffer);
-		return TRUE;
+		return success;
 	}
 	g_free (buffer);
 	return FALSE;
@@ -1140,6 +1141,8 @@ desktop_icon_info_open (DesktopIconInfo *dii)
 		if (!is_mounted){
 			if (try_to_mount (filename, fe))
 				launch = TRUE;
+			else
+				launch = FALSE;
 		} else
 			launch = TRUE;
 		
@@ -1531,7 +1534,7 @@ icon_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 		break;
 
 	case GDK_BUTTON_RELEASE:
-		if (event->button.button != 1 || event->button.button != 2)
+		if (!(event->button.button == 1 || event->button.button != 2))
 			break;
 
 		if (on_text && icon_select_on_text) {
