@@ -8,6 +8,7 @@
 #include "filegui.h"
 #include "fileopctx.h"
 #include "eregex.h"
+#include "main.h"
 #include "../vfs/vfs.h"
 
 enum {
@@ -224,8 +225,9 @@ file_progress_show_deleting (FileOpContext *ctx, char *path)
 FileProgressStatus
 file_progress_show (FileOpContext *ctx, long done, long total)
 {
-        static gchar count[10];
+        static gchar count[20];
         FileOpContextUI *ui;
+        double perc;
 
         g_return_val_if_fail (ctx != NULL, FILE_CONT);
 
@@ -238,8 +240,14 @@ file_progress_show (FileOpContext *ctx, long done, long total)
         if (ui->aborting)
                 return FILE_ABORT;
         
-        snprintf (count, 9, "%d%%", (gint)(100.0 *(gfloat)done/(gfloat)total));
-        gtk_label_set_text (GTK_LABEL (ui->file_label), count);
+        if (total > 0) {
+                perc = (double) done / (double) total;
+                snprintf (count, 9, "%d%%", (gint) (100.0 * perc));
+                gtk_label_set_text (GTK_LABEL (ui->file_label), count);
+                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), perc);
+        } else
+                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), 0.0);
+
         while (gtk_events_pending ())
                 gtk_main_iteration ();
 	return FILE_CONT;
@@ -273,6 +281,7 @@ FileProgressStatus
 file_progress_show_bytes (FileOpContext *ctx, double done, double total)
 {
         FileOpContextUI *ui;
+        double perc;
 
         g_return_val_if_fail (ctx != NULL, FILE_CONT);
 
@@ -285,11 +294,9 @@ file_progress_show_bytes (FileOpContext *ctx, double done, double total)
         if (ui->aborting)
                 return FILE_ABORT;
 
-        if (total == 0.0)
-                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), 0.0);
-        else
-                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog),
-                                         (gfloat) done/(gfloat) total);
+        perc = done / total;
+        gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), CLAMP (perc, 0.0, 1.0));
+
         while (gtk_events_pending ())
                 gtk_main_iteration ();
 	return FILE_CONT;
@@ -928,3 +935,111 @@ fmd_init_i18n (int force)
 {
         /* unneccessary func */
 }
+
+/* Callback for the gnome_request_dialog() in the input dialog */
+static void
+input_dialog_cb (gchar *string, gpointer data)
+{
+        char **s;
+
+        s = data;
+        *s = string;
+
+        gtk_main_quit ();
+}
+
+/* Our implementation of the general-purpose input dialog */
+char *
+real_input_dialog_help (char *header, char *text, char *help, char *def_text)
+{
+        int is_password;
+        GtkWidget *dialog;
+        char *string;
+
+        if (strncmp (text, _("Password:"), strlen (_("Password"))) == 0)
+                is_password = TRUE;
+        else
+                is_password = FALSE;
+
+        dialog = gnome_request_dialog (is_password, text, def_text, 0,
+                                       input_dialog_cb, &string,
+                                       NULL);
+        gtk_window_set_title (GTK_WINDOW (dialog), header);
+        gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+        gtk_main ();
+        return string;
+}
+
+/* Our implementation of the symlink-to dialog */
+void
+symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
+{
+        GtkWidget *dialog;
+        GtkWidget *vbox;
+        GtkWidget *w;
+        GtkWidget *entry1, *entry2;
+        WPanel *panel;
+        int ret;
+
+        g_return_if_fail (existing != NULL);
+        g_return_if_fail (new != NULL);
+        g_return_if_fail (ret_existing != NULL);
+        g_return_if_fail (ret_new != NULL);
+
+        /* Create the dialog */
+
+        dialog = gnome_dialog_new (_("Symbolic Link"),
+                                   GNOME_STOCK_BUTTON_OK,
+                                   GNOME_STOCK_BUTTON_CANCEL,
+                                   NULL);
+        gnome_dialog_close_hides (GNOME_DIALOG (dialog), TRUE);
+        gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
+
+        panel = cpanel;
+        if (!is_a_desktop_panel (panel))
+                gnome_dialog_set_parent (GNOME_DIALOG (dialog), panel->xwindow);
+
+        /* File symlink will point to */
+
+        vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), vbox, FALSE, FALSE, 0);
+
+        w = gtk_label_new (_("Existing filename (filename symlink will point to):"));
+        gtk_misc_set_alignment (GTK_MISC (w), 0.0, 0.5);
+        gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
+
+        entry1 = gtk_entry_new ();
+        gtk_entry_set_text (GTK_ENTRY (entry1), existing);
+        gtk_box_pack_start (GTK_BOX (vbox), entry1, FALSE, FALSE, 0);
+        gnome_dialog_editable_enters (GNOME_DIALOG (dialog), GTK_EDITABLE (entry1));
+
+        /* Name of symlink */
+
+        vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), vbox, FALSE, FALSE, 0);
+
+        w = gtk_label_new (_("Symbolic link filename:"));
+        gtk_misc_set_alignment (GTK_MISC (w), 0.0, 0.5);
+        gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
+
+        entry2 = gtk_entry_new ();
+        gtk_entry_set_text (GTK_ENTRY (entry2), new);
+        gtk_box_pack_start (GTK_BOX (vbox), entry2, FALSE, FALSE, 0);
+        gnome_dialog_editable_enters (GNOME_DIALOG (dialog), GTK_EDITABLE (entry2));
+        gtk_widget_grab_focus (entry2);
+
+        /* Run */
+
+        gtk_widget_show_all (GNOME_DIALOG (dialog)->vbox);
+        ret = gnome_dialog_run (GNOME_DIALOG (dialog));
+
+        if (ret != 0) {
+                *ret_existing = NULL;
+                *ret_new = NULL;
+        } else {
+                *ret_existing = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry1)));
+                *ret_new = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry2)));
+        }
+
+        gtk_widget_destroy (dialog);
+}
