@@ -113,8 +113,6 @@ gnome_file_property_dialog_finalize (GtkObject *object)
 
 	if (gfpd->file_name)
 		g_free (gfpd->file_name);
-	if (gfpd->im)
-		gdk_imlib_destroy_image (gfpd->im);
 	if (gfpd->fm_open)
 		g_free (gfpd->fm_open);
 	if (gfpd->fm_view)
@@ -440,14 +438,11 @@ generate_icon_sel (GnomeFilePropertyDialog *fp_dlg)
 	
 	retval = gnome_icon_entry_new ("gmc_file_icon", "Select an Icon");
 	icon = g_strdup (gicon_get_filename_for_icon (fp_dlg->im));
-	if (icon)
+
+	if (icon == NULL)
 		return retval;
-	
-	if (icon[0]){
-		return retval;
-	}
 	gnome_icon_entry_set_icon (GNOME_ICON_ENTRY (retval), icon);
-	fp_dlg->icon_filename = g_strdup (icon);
+	fp_dlg->icon_filename = icon;
 	return retval;
 }
 
