@@ -139,7 +139,7 @@
 
 #include "popt.h"
 
-/* "$Id: main.c,v 1.84 1999/03/11 02:00:33 unammx Exp $" */
+/* "$Id: main.c,v 1.86 1999/03/18 18:44:02 unammx Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -2751,7 +2751,7 @@ handle_args (int argc, char *argv [])
     gtk_widget_push_visual (gdk_imlib_get_visual ());
     gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 	
-    poptResetContext (ctx);
+/*    poptResetContext (ctx); */
 #else
     ctx = poptGetContext ("mc", argc, argv, argument_table, 0);
 #endif
@@ -3056,7 +3056,19 @@ int main (int argc, char *argv [])
     if (alternate_plus_minus)
         application_keypad_mode ();
 #   endif
-
+/* INSERT ROOT DIALOG HERE */
+#ifdef HAVE_GNOME
+    if (geteuid () == 0) {
+	    GtkWidget *warning_dlg;
+	    warning_dlg = gnome_message_box_new (_("You are running the GNOME Midnight Commander as root. \n\n"
+					   "You will not be protected from severly damaging your system\n"
+					   "if you continue."),
+					   GNOME_MESSAGE_BOX_WARNING,
+					   _("Continue"), GNOME_STOCK_BUTTON_CANCEL, NULL);
+	    if (gnome_dialog_run (GNOME_DIALOG (warning_dlg)) != 0)
+		    exit (0);
+    }
+#endif
     if (show_change_notice){
 	message (1, _(" Notice "),
 		 _(" The Midnight Commander configuration files \n"
