@@ -28,7 +28,7 @@
 
 /* }}} */
 
-/*  [] = "$Id: wtools.c,v 1.14 1999/01/27 01:09:43 timur Exp $" */
+/*  [] = "$Id: wtools.c,v 1.16 1999/03/16 20:46:57 unammx Exp $" */
 
 #include <config.h>
 #include <string.h>
@@ -551,6 +551,8 @@ int quick_dialog (QuickDialog *qd)
 /* }}} */
 
 /* {{{ Input routines */
+
+#ifndef HAVE_GNOME
 #define INPUT_INDEX 2
 char *real_input_dialog_help (char *header, char *text, char *help, char *def_text)
 {
@@ -573,11 +575,7 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
 /* we need a unique name for tkname because widget.c:history_tool()
    needs a unique name for each dialog - using the header is ideal */
 
-#ifdef HAVE_GNOME
-    strncpy (tk_name + 4, header, 59);
-#else
     strncpy (tk_name + 3, header, 60);
-#endif
     tk_name[63] = '\0';
     quick_widgets[2].tkname = tk_name;
 
@@ -626,72 +624,13 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
     } else
 	return 0;
 }
+#endif
 
 char *input_dialog (char *header, char *text, char *def_text)
 {
     return input_dialog_help (header, text, "[Input Line Keys]", def_text);
 }
 
-static int
-input_dialog_help_2 (char *header, char *text1, char *text2, char *help, char **r1, char **r2)
-{
-    QuickDialog Quick_input;
-    QuickWidget quick_widgets [] = {
-    { quick_button, 6, 10, 4, 0, N_("&Cancel"), 0, B_CANCEL, 0, 0,
-	  XV_WLAY_DONTCARE, "button-cancel" },
-    { quick_button, 3, 10, 4, 0, N_("Ok")
-, 0, B_ENTER, 0, 0,
-	  XV_WLAY_DONTCARE, "button-ok" },
-    { quick_input,  4, 80, 4, 0, "", 58, 0, 0, 0, XV_WLAY_BELOWCLOSE, "input-pth" },
-    { quick_label,  3, 80, 3, 0, "", 0, 0, 0, 0, XV_WLAY_DONTCARE, "label-pth" },
-    { quick_input,  4, 80, 3, 0, "", 58, 0, 0, 0, XV_WLAY_BELOWCLOSE, "input-lbl" },
-    { quick_label,  3, 80, 2, 0, "", 0, 0, 0, 0, XV_WLAY_DONTCARE, "label-lbl" },
-    { 0 } };
-    
-    int len;
-    int i;
-    int lines1, lines2;
-    char *my_str1, *my_str2;
-    
-    len = max (strlen (header), msglen (text1, &lines1));
-    len = max (len, msglen (text2, &lines2)) + 4;
-    len = max (len, 64);
-
-    Quick_input.xlen  = len;
-    Quick_input.xpos  = -1;
-    Quick_input.title = header;
-    Quick_input.help  = help;
-    Quick_input.class = "quick_input_2";
-    Quick_input.i18n  = 0;
-    quick_widgets [5].text = text1;
-    quick_widgets [3].text = text2;
-
-    for (i = 0; i < 6; i++)
-	quick_widgets [i].y_divisions = lines1+lines2+7;
-    Quick_input.ylen  = lines1 + lines2 + 7;
-
-    quick_widgets [0].relative_y += (lines1 + lines2);
-    quick_widgets [1].relative_y += (lines1 + lines2);
-    quick_widgets [2].relative_y += (lines1);
-    quick_widgets [3].relative_y += (lines1);
-
-    quick_widgets [4].str_result = &my_str1;
-    quick_widgets [2].str_result = &my_str2;
-    
-    Quick_input.widgets = quick_widgets;
-    if (quick_dialog (&Quick_input) != B_CANCEL){
-	 *r1 = *(quick_widgets [4].str_result);
-	 *r2 = *(quick_widgets [2].str_result);
-	 return 1;
-    } else
-	 return 0;
-}
-
-int input_dialog_2 (char *header, char *text1, char *text2, char **r1, char **r2)
-{
-    return input_dialog_help_2 (header, text1, text2,  "[Input Line Keys]", r1, r2);
-}
-
 char *input_expand_dialog (char *header, char *text, char *def_text)
 {
     char *result;
